html,body{margin:0;padding:0}body{background:#efeff4 url(../images/loading.svg) 0 0 no-repeat}iframe{display:block;width:100%;height:400px;border:none;margin:0;padding:0}

/*# sourceMappingURL=duo.03d3232066d89682b1ee.css.map*/