@font-face {
  font-family: "Open Sans";
  font-style: italic;
  font-weight: 300;
  src: url(../fonts/Open_Sans-italic-300.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

@font-face {
  font-family: "Open Sans";
  font-style: italic;
  font-weight: 400;
  src: url(../fonts/Open_Sans-italic-400.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

@font-face {
  font-family: "Open Sans";
  font-style: italic;
  font-weight: 600;
  src: url(../fonts/Open_Sans-italic-600.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

@font-face {
  font-family: "Open Sans";
  font-style: italic;
  font-weight: 700;
  src: url(../fonts/Open_Sans-italic-700.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

@font-face {
  font-family: "Open Sans";
  font-style: italic;
  font-weight: 800;
  src: url(../fonts/Open_Sans-italic-800.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

@font-face {
  font-family: "Open Sans";
  font-style: normal;
  font-weight: 300;
  src: url(../fonts/Open_Sans-normal-300.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

@font-face {
  font-family: "Open Sans";
  font-style: normal;
  font-weight: 400;
  src: url(../fonts/Open_Sans-normal-400.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

@font-face {
  font-family: "Open Sans";
  font-style: normal;
  font-weight: 600;
  src: url(../fonts/Open_Sans-normal-600.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

@font-face {
  font-family: "Open Sans";
  font-style: normal;
  font-weight: 700;
  src: url(../fonts/Open_Sans-normal-700.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

@font-face {
  font-family: "Open Sans";
  font-style: normal;
  font-weight: 800;
  src: url(../fonts/Open_Sans-normal-800.woff) format("woff");
  unicode-range: U+0-10FFFF;
}

body {
  font-family: "Open Sans";
}

html,
body,
.row {
  height: 100%;
  -webkit-font-smoothing: antialiased;
}

h2 {
  font-size: 25px;
  margin-bottom: 12.5px;
  font-weight: 500;
  line-height: 1.1;
}

.brand {
  font-size: 23px;
  line-height: 25px;
  color: #fff;
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
}

.banner {
  background-color: #175ddc;
  height: 56px;
}

.content {
  padding-top: 20px;
  padding-bottom: 20px;
  padding-left: 15px;
  padding-right: 15px;
}

.footer {
  padding: 40px 0 40px 0;
  border-top: 1px solid #dee2e6;
}

/* Bitwarden icons, manually copied */

@font-face {
  font-family: "bwi-font";
  src: url(../images/bwi-font.svg) format("svg"), url(../fonts/bwi-font.ttf) format("truetype"),
    url(../fonts/bwi-font.woff) format("woff"), url(../fonts/bwi-font.woff2) format("woff2");
  font-weight: normal;
  font-style: normal;
  font-display: block;
}

.bwi {
  /* use !important to prevent issues with browser extensions that change fonts */
  font-family: "bwi-font" !important;
  speak: never;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  display: inline-block;
  /* Better Font Rendering */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.bwi-shield:before {
  content: "\e932";
}
