(()=>{"use strict";var e={31848:(e,o)=>{Object.defineProperty(o,"__esModule",{value:!0}),o.b64Decode=o.getQsParam=void 0,o.getQsParam=function(e){const o=window.location.href;e=e.replace(/[\[\]]/g,"\\$&");const t=new RegExp("[?&]"+e+"(=([^&#]*)|&|#|$)").exec(o);return t?t[2]?decodeURIComponent(t[2].replace(/\+/g," ")):"":null},o.b64Decode=function(e,o=!1){return o&&(e=e.replace(/ /g,"+")),decodeURIComponent(Array.prototype.map.call(atob(e),(e=>"%"+("00"+e.charCodeAt(0).toString(16)).slice(-2))).join(""))}},57109:(e,o,t)=>{t.r(o)}},o={};function t(n){var r=o[n];if(void 0!==r)return r.exports;var c=o[n]={exports:{}};return e[n](c,c.exports,t),c.exports}t.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})};(()=>{const e=t(31848);t(57109),document.addEventListener("DOMContentLoaded",(()=>{const o=e.getQsParam("code"),t=e.getQsParam("state");if(null!=t&&t.includes(":clientId=browser"))!function(e,o){window.postMessage({command:"authResult",code:e,state:o},"*");const t=("; "+document.cookie).split("; ssoHandOffMessage=").pop().split(";").shift();document.cookie="ssoHandOffMessage=;SameSite=strict;max-age=0";const n=document.getElementById("content");n.innerHTML="";const r=document.createElement("p");r.innerText=t,n.appendChild(r)}(o,t);else{window.location.href=window.location.origin+"/#/sso?code="+o+"&state="+t;const e=function(e,o){const t=new RegExp(o).exec(e);if(!t)return null;return t[0]}(t,"(?<=_returnUri=')(.*)(?=')");window.location.href=e?window.location.origin+`/#${e}`:window.location.origin+"/#/sso?code="+o+"&state="+t}}))})()})();
//# sourceMappingURL=sso.3e58297e1e9fa274f91c.js.map